API Reference
=============

.. autoclass:: group_lasso.GroupLasso
    :inherited-members:

.. autoclass:: group_lasso.LogisticGroupLasso
    :inherited-members:

.. autoclass:: group_lasso.MultinomialGroupLasso
    :inherited-members:

